@@ -87,12 +87,23 @@ get_config <- function() {
 #' @export
 set_config <- function(svc, cfgs = list()) {
   shape <- tag_annotate(Config())
+
+  # update optional config parameters
+  cfgs <- update_optional_config_parameter(cfgs, cfgs$credentials$profile)
   config <- populate(cfgs, shape)
   config$credentials <- as.environment(config$credentials)
   svc$.internal <- list(config = config)
   return(svc)
 }
 
+update_optional_config_parameter <- function(cfgs, profile) {
+  for (cfg_param in names(.optional_config_parameter)) {
+    if (is.null(cfgs[[cfg_param]]))
+      cfgs[[cfg_param]] <- .optional_config_parameter[[cfg_param]](profile)
+  }
+  return(cfgs)
+}
+
 #-------------------------------------------------------------------------------
 #-------------------------------------------------------------------------------
 #-------------------------------------------------------------------------------
@@ -332,3 +343,88 @@ get_web_identity_token_file <- function(web_identity_token_file = "") {
 
   return(web_identity_token_file)
 }
+
+# Check if sts_regional_endpoint is present in config file
+check_config_file_sts_regional_endpoint <- function(profile = "") {
+  config_path <- get_config_file_path()
+  if (is.null(config_path)) {
+    return(NULL)
+  }
+
+  profile <- get_profile_name(profile)
+  if (profile != "default") profile <- paste("profile", profile)
+
+  config_values <- read_ini(config_path)
+
+  if (is.null(config_values[[profile]])) {
+    return(NULL)
+  }
+
+  sts_regional_endpoint <- config_values[[profile]]$sts_regional_endpoint
+
+  return(sts_regional_endpoint)
+}
+
+# Get the AWS STS Regional Endpoint property from envvar or
+# config file. Envvar takes precedence as per general AWS strategy
+get_sts_regional_endpoint <- function(profile = "") {
+  sts_regional_endpoint <- get_env("AWS_STS_REGIONAL_ENDPOINTS")
+  if (sts_regional_endpoint != "") {
+    return(sts_regional_endpoint)
+  }
+
+  sts_regional_endpoint <- check_config_file_sts_regional_endpoint(profile)
+
+  return(sts_regional_endpoint %||% "")
+}
+
+.optional_config_parameter <- list(
+  "sts_regional_endpoint" = get_sts_regional_endpoint
+)
+
+# Ensures config is built correctly from service parameters
+build_config <- function(cfg){
+  add_list <- function(x) if(length(x) == 0) NULL else x
+
+  creds <- list()
+  credentials <- list()
+  config <- list()
+
+  cred_names <- names(Creds())
+  credentails_names <- names(Credentials())
+  cred_names <- cred_names[cred_names != "provider_name"]
+  credentails_names <- credentails_names[credentails_names != "provider"]
+
+  for (cfg_name in names(cfg)) {
+    if (cfg_name == "credentials") {
+      for (credentails_name in credentails_names) {
+        if (credentails_name == "creds") {
+          for (cred_name in cred_names) {
+            creds[[cred_name]] <- cfg[[cfg_name]][[credentails_name]][[cred_name]]
+          }
+          credentials[[credentails_name]] <- add_list(creds)
+        } else {
+          credentials[[credentails_name]] <- cfg[[cfg_name]][[credentails_name]]
+        }
+      }
+      config[[cfg_name]] <- add_list(credentials)
+    } else {
+      config[[cfg_name]] <- cfg[[cfg_name]]
+    }
+  }
+  return(config)
+}
+
+#' @title Merges config lists for paws services
+#' @description Allows config list to be flatten from shorthand.
+#' @param orig_cfg Original config list
+#' @param param_cfg Config list developed from service parameters
+#' @keywords internal
+#' @export
+merge_config <- function(orig_cfg, param_cfg) {
+  if (identical(param_cfg$credentials, credentials())) {
+    param_cfg$credentials <- list()
+  }
+  built_cfg <- build_config(param_cfg)
+  return(modifyList(orig_cfg, built_cfg))
+}
